Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GetEnv ¶
GetEnv takes the name of the environment variable as the first parameter. If the environment variable is found, the value is returned. If the environment variable is not found, the second parameter is used for a default value. If the second parameter is not set, an error is returned. You may choose to provide default value depending on your needs.
func GetEnvAsBool ¶
GetEnvAsBool takes the name of the environment variable as the first parameter. If the environment variable is found and the value is of type boolean, the value is returned. If the environment variable is not found, the second parameter is used for a default value. If the second parameter is not set, an error is returned. You may choose to provide default value depending on your needs.
func GetEnvAsInt ¶
GetEnvAsInt takes the name of the environment variable as the first parameter. If the environment variable is found and the value is of type integer, the value is returned. If the environment variable is not found, the second parameter is used for a default value. If the second parameter is not set, an error is returned. You may choose to provide default value depending on your needs.
Types ¶
This section is empty.