Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewServer ¶
func NewServer(handler http.Handler, config ServerConfig) *server
NewServer creates a new server instance with the given handler and configuration.
Types ¶
type CleanupHandler ¶
CleanupHandler is an interface that allows components (e.g., DB, workers) to hook into the server shutdown and clean up resources gracefully.
Click to show internal directories.
Click to hide internal directories.